@@ -1,7 +1,7 @@
 import numpy as np
 from gastimator import gastimator
-#from time import sleep
-
+import time
+t=time.time()
 def gaussian(values,x):
     mu=values[0]
     sigma=values[1]
@@ -25,9 +25,10 @@ mcmc.max=np.array([50.,20.]) # ... and these maximum values
 mcmc.fixed=np.array([False, False]) #if you would like to fix a variable then you can set its value to True here.
 mcmc.precision=np.array([1.,1.]) #here we assume we can get the intercept and gradient within ±1.0 - very conservative
 mcmc.prior_func=(None,None)
-nsamples=100000
+nsamples=1000000
 
 #mcmc.input_checks()
 #print(mcmc.prior_func)
 #mcmc.nprocesses=1
-outputvalue, outputll= mcmc.run(data,1e-3,nsamples,nchains=3,plot=False)    
\ No newline at end of file
+outputvalue, outputll= mcmc.run(data,1e-3,nsamples,nchains=3,plot=False)    
+print("Time taken:",time.time()-t)
\ No newline at end of file
