@@ -3,13 +3,14 @@ from gastimator import gastimator
 import matplotlib.pyplot as plt
 from gastimator import priors
 from gastimator import corner_plot
-
+from time import sleep
 
 
 
 def ratio(values,x):
     a=values[0]
     b=values[1]
+    #sleep(0.05)
     return (a/b)*x
     
 truth=np.array([30,5])
@@ -33,8 +34,8 @@ nsamples=100000
 
 #mcmc.input_checks()
 #print(mcmc.prior_func)
-#mcmc.nprocesses=1
-outputvalue, outputll= mcmc.run(data,error,nsamples,nchains=3,plot=False)    
+mcmc.nprocesses=5
+outputvalue, outputll= mcmc.run(data,error,nsamples,nchains=5,plot=True)    
 
 figure = corner_plot.corner_plot(outputvalue.T,like=outputll,labels=mcmc.labels,quantiles=[0.16, 0.5, 0.84], truths=truth)
 plt.show()
\ No newline at end of file
